@@ -1,6 +1,6 @@
 package Map::Tube::London;
 
-$Map::Tube::London::VERSION   = '0.53';
+$Map::Tube::London::VERSION   = '0.54';
 $Map::Tube::London::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Map::Tube::London - Interface to the London Tube Map.
 
 =head1 VERSION
 
-Version 0.53
+Version 0.54
 
 =cut
 
@@ -110,29 +110,31 @@ On error it returns an object of type L<Map::Tube::Exception>.
 
 =head2 as_image($line_name)
 
-Returns line image as base64 encoded string. It expects the plugin L<Map::Tube::Plugin::Graph>
-to be installed.
+It expects the plugin  L<Map::Tube::Plugin::Graph> to be  installed. Returns line
+image  as  base64  encoded string if C<$line_name> passed in otherwise it returns
+base64 encoded string of the entire map.
 
     use strict; use warnings;
     use MIME::Base64;
     use Map::Tube::London;
 
     my $tube = Map::Tube::London->new;
-    my $line = 'Central';
-    open(my $IMAGE, ">$line.png");
-    print $IMAGE decode_base64($tube->as_image($line));
+    my $map  = $tube->name;
+    open(my $IMAGE, ">$map.png");
+    binmode($IMAGE);
+    print $IMAGE decode_base64($tube->as_image);
     close($IMAGE);
 
-The L<Central Line|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Central.png>
+The L<London Tube Map|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/London-Tube.png>
 map as generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
-<a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Central.png">
-<img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Central.png"
-     alt    = "London Tube Map: Central Line"
-     width  = "500px"
-     height = "500px"/>
+<a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/London-Tube.png">
+<img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/London-Tube.png"
+     alt    = "London Tube Map"
+     width  = "540px"
+     height = "780px"/>
 </a>
 
 =end html
